package ru.myitschool.work.ui.main

import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.api.EmployeeData
import javax.inject.Inject

@HiltViewModel
class MainViewModel @Inject constructor(
    private val apiService: ApiService
) : ViewModel() {

    private val _employeeData = MutableStateFlow<EmployeeData?>(null)
    val employeeData: StateFlow<EmployeeData?> get() = _employeeData

    private val _errorMessage = MutableStateFlow<String?>(null)
    val errorMessage: StateFlow<String?> get() = _errorMessage

    fun fetchUserInfo(login: String, authHeader: String) {
        viewModelScope.launch {
            try {
                val response = apiService.getUserInfo(login, authHeader)
                if (response.isSuccessful) {
                    _employeeData.value = response.body()
                } else {
                    _errorMessage.value = "Ошибка получения данных: ${response.message()}"
                }
            } catch (e: Exception) {
                Log.e("MainViewModel", "Error fetching user info", e)
                _errorMessage.value = "Ошибка сети: ${e.message}"
            }
        }
    }
}