package ru.myitschool.work.ui.login

import ru.myitschool.work.api.ApiService
import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch
import ru.myitschool.work.SessionManager
import javax.inject.Inject

@HiltViewModel
class LoginViewModel @Inject constructor(
    private val apiService: ApiService
) : ViewModel() {

    private val _state = MutableStateFlow(LoginState())
    val state: StateFlow<LoginState> get() = _state

    fun authenticate(username: String, password: String) {
        Log.d("LoginViewModel", "Authenticating user: $username") // Логируем начало аутентификации

        if (isValidUsername(username)) {
            viewModelScope.launch {
                try {
                    Log.d("LoginViewModel", "Sending authentication request to server") // Логируем отправку запроса
                    val response = apiService.authenticate(username, password)
                    Log.d("LoginViewModel", "Response code: ${response.code()}") // Логируем код ответа

                    // Проверяем код ответа
                    when (response.code()) {
                        200 -> {
                            SessionManager.userLogin = username
                            _state.value = LoginState(success = true) // Успешная авторизация
                            Log.d("LoginViewModel", "Authentication successful") // Логируем успешную аутентификацию
                        }
                        400 -> {
                            _state.value = LoginState(error = "Ошибка авторизации: Неверные учетные данные.")
                            Log.d("LoginViewModel", "Authentication failed: Invalid credentials") // Логируем ошибку
                        }
                        else -> {
                            _state.value = LoginState(error = "Ошибка авторизации: ${response.message()}")
                            Log.d("LoginViewModel", "Authentication failed: ${response.message()}") // Логируем ошибку
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                    _state.value = LoginState(error = "Ошибка сети. Проверьте подключение к интернету.")
                    Log.e("LoginViewModel", "Network error: ${e.message}") // Логируем ошибку сети
                }
            }
        } else {
            _state.value = LoginState(error = "Неправильный логин")
            Log.d("LoginViewModel", "Invalid username: $username") // Логируем неправильный логин
        }
    }

    private fun isValidUsername(username: String): Boolean {
        return username.isNotEmpty() // Пример проверки логина
    }
}

// Состояние аутентификации
data class LoginState(
    val success: Boolean = false, // Успешность аутентификации
    val error: String? = null, // Сообщение об ошибке
    val maintenance: Boolean = false // Состояние техобслуживания
)